methylMnM-package:
MeDIP-Seq and MRE-Seq data analysis
Description
M&M was developed for analyzing data derived from methylated DNA immunoprecipitation (MeDIP) experiments followed by sequencing (MeDIP-Seq) and
the digestions with the methyl-sensitive restriction enzymes (MRE-Seq).
Nevertheless, functionalities like the quality controls may be applied to other types of sequencing data (e.g. ChIP-Seq).
MeDIP-MRE (methylMnM) test which combine the two differential techniques
(MeDIP-seq and MRE-seq) data to detecting the differentially methylation level of CpG.
Details
|
Package: |
| methylMnM |
|
Type: |
| Package |
|
Version: |
| 1.0 |
|
Date: |
| 2012-12-01 |
|
License: |
| GPL-3 |
|
LazyLoad: |
| yes |
|
Depends: |
| R (>= 2.12.0) |
References
Yan Zhou, Bo Zhang, Nan Lin, BaoXue Zhang and Ting Wang, 2012